@@ -607,11 +607,6 @@ class FunctionsTest(unittest.TestCase):
                 pass
         A(1, 2)
 
-    def test_import_module(self):
-        self.assertEqual("generallibrary", import_module("generallibrary").__name__)
-        self.assertEqual("pandas", import_module("pandas").__name__)
-        self.assertEqual(None, import_module("doesntexist", error=False))
-
     def test_terminal(self):
         self.assertEqual(0, terminal("-c", "assert 5 == 5", python=True))
         with self.assertRaises(Exception):
