@@ -8,7 +8,6 @@ from generallibrary.functions import initBases
 from generallibrary.decorators import Operators
 
 from packaging import version
-import pkg_resources
 from distutils.version import StrictVersion
 import re
 
@@ -235,13 +234,3 @@ class PythonVersion(DuckTyping):
         return self._version
 
 
-def get_installed_packages():
-    """ Get a list of all installed packages as strings. """
-    return [pkg.key for pkg in pkg_resources.working_set]
-
-
-def package_is_installed(*names):
-    """ Returns whether a package is installed. """
-    return all([name in get_installed_packages() for name in names])
-
-
